@@ -96,7 +96,8 @@ class AdsAPI(object):
     """A client for the Facebook Ads API."""
     DATA_LIMIT = 100
 
-    def __init__(self, access_token, app_id, app_secret):
+    def __init__(self, access_token, app_id='', app_secret=''):
+        # Most ad account operations can be done without an app id and secret, so allow creating without them.
         self.access_token = access_token
         self.app_id = app_id
         self.app_secret = app_secret
@@ -396,7 +397,7 @@ class AdsAPI(object):
     def get_adreport_stats2(self, account_id, data_columns, date_preset=None,
                             date_start=None, date_end=None,
                             time_increment=None, actions_group_by=None,
-                            filters=None, async=False, batch=False):
+                            filters=None, async=False, batch=False, offset=None):
         """Returns the ad report stats for the given account."""
         if date_preset is None and date_start is None and date_end is None:
             raise BaseException("Either a date_preset or a date_start/end \
@@ -407,6 +408,8 @@ class AdsAPI(object):
         }
         if date_preset:
             args['date_preset'] = date_preset
+        if offset:
+            args['offset'] = offset
         if date_start and date_end:
             args['time_interval'] = \
                 self.get_time_interval(date_start, date_end)
@@ -809,27 +812,7 @@ class AdsAPI(object):
         path = '%s' % campaign_id
         return self.make_request(path, 'DELETE', batch=batch)
 
-    # this method is deprecated
-    def create_adcreative_type_27(self, account_id, object_id,
-                                  auto_update=None, story_id=None,
-                                  url_tags=None, name=None, batch=False):
-        """Creates an ad creative in the given ad account."""
         logger.warn("This method is deprecated and is replaced with get_ads_pixels.")
-        path = 'act_%s/adcreatives' % account_id
-        args = {
-            'type': 27,
-            'object_id': object_id,
-        }
-        if auto_update:
-            args['auto_update'] = auto_update
-        if story_id:
-            args['story_id'] = story_id
-        if url_tags:
-            args['url_tags'] = url_tags
-        if name:
-            args['name'] = name
-        return self.make_request(path, 'POST', args, batch=batch)
-
     def create_adcreative(self, account_id, object_story_id=None, batch=False):
         """Creates an ad creative in the given ad account."""
         path = 'act_%s/adcreatives' % account_id
